# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsMessagingReportListItemModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp_epoch': 'int',
        'total_messages': 'int',
        'outgoing_messages': 'int',
        'incoming_messages': 'int',
        'outgoing_bot': 'int',
        'outgoing_automation': 'int',
        'outgoing_macro': 'int',
        'outgoing_agent': 'int',
        'outgoing_contact_action': 'int',
        'outgoing_scheduled': 'int',
        'outgoing_api': 'int',
        'outgoing_channel_app': 'int',
        'outgoing_agent_app': 'int',
        'outgoing_customer_app': 'int',
        'engaged_customers': 'int',
        'outgoing_messages_text': 'int',
        'outgoing_messages_instant_app': 'int',
        'outgoing_messages_file': 'int',
        'outgoing_messages_mms': 'int',
        'outgoing_messages_system': 'int',
        'outgoing_contact_action_manual': 'int',
        'outgoing_contact_action_auto': 'int',
        'incoming_messages_text': 'int',
        'incoming_messages_mms': 'int',
        'total_segments': 'int',
        'outgoing_segments': 'int',
        'incoming_segments': 'int'
    }

    attribute_map = {
        'timestamp_epoch': 'timestampEpoch',
        'total_messages': 'totalMessages',
        'outgoing_messages': 'outgoingMessages',
        'incoming_messages': 'incomingMessages',
        'outgoing_bot': 'outgoingBot',
        'outgoing_automation': 'outgoingAutomation',
        'outgoing_macro': 'outgoingMacro',
        'outgoing_agent': 'outgoingAgent',
        'outgoing_contact_action': 'outgoingContactAction',
        'outgoing_scheduled': 'outgoingScheduled',
        'outgoing_api': 'outgoingApi',
        'outgoing_channel_app': 'outgoingChannelApp',
        'outgoing_agent_app': 'outgoingAgentApp',
        'outgoing_customer_app': 'outgoingCustomerApp',
        'engaged_customers': 'engagedCustomers',
        'outgoing_messages_text': 'outgoingMessagesText',
        'outgoing_messages_instant_app': 'outgoingMessagesInstantApp',
        'outgoing_messages_file': 'outgoingMessagesFile',
        'outgoing_messages_mms': 'outgoingMessagesMms',
        'outgoing_messages_system': 'outgoingMessagesSystem',
        'outgoing_contact_action_manual': 'outgoingContactActionManual',
        'outgoing_contact_action_auto': 'outgoingContactActionAuto',
        'incoming_messages_text': 'incomingMessagesText',
        'incoming_messages_mms': 'incomingMessagesMms',
        'total_segments': 'totalSegments',
        'outgoing_segments': 'outgoingSegments',
        'incoming_segments': 'incomingSegments'
    }

    def __init__(self, timestamp_epoch=None, total_messages=None, outgoing_messages=None, incoming_messages=None, outgoing_bot=None, outgoing_automation=None, outgoing_macro=None, outgoing_agent=None, outgoing_contact_action=None, outgoing_scheduled=None, outgoing_api=None, outgoing_channel_app=None, outgoing_agent_app=None, outgoing_customer_app=None, engaged_customers=None, outgoing_messages_text=None, outgoing_messages_instant_app=None, outgoing_messages_file=None, outgoing_messages_mms=None, outgoing_messages_system=None, outgoing_contact_action_manual=None, outgoing_contact_action_auto=None, incoming_messages_text=None, incoming_messages_mms=None, total_segments=None, outgoing_segments=None, incoming_segments=None):  # noqa: E501
        """AnalyticsMessagingReportListItemModel - a model defined in Swagger"""  # noqa: E501
        self._timestamp_epoch = None
        self._total_messages = None
        self._outgoing_messages = None
        self._incoming_messages = None
        self._outgoing_bot = None
        self._outgoing_automation = None
        self._outgoing_macro = None
        self._outgoing_agent = None
        self._outgoing_contact_action = None
        self._outgoing_scheduled = None
        self._outgoing_api = None
        self._outgoing_channel_app = None
        self._outgoing_agent_app = None
        self._outgoing_customer_app = None
        self._engaged_customers = None
        self._outgoing_messages_text = None
        self._outgoing_messages_instant_app = None
        self._outgoing_messages_file = None
        self._outgoing_messages_mms = None
        self._outgoing_messages_system = None
        self._outgoing_contact_action_manual = None
        self._outgoing_contact_action_auto = None
        self._incoming_messages_text = None
        self._incoming_messages_mms = None
        self._total_segments = None
        self._outgoing_segments = None
        self._incoming_segments = None
        self.discriminator = None
        if timestamp_epoch is not None:
            self.timestamp_epoch = timestamp_epoch
        if total_messages is not None:
            self.total_messages = total_messages
        if outgoing_messages is not None:
            self.outgoing_messages = outgoing_messages
        if incoming_messages is not None:
            self.incoming_messages = incoming_messages
        if outgoing_bot is not None:
            self.outgoing_bot = outgoing_bot
        if outgoing_automation is not None:
            self.outgoing_automation = outgoing_automation
        if outgoing_macro is not None:
            self.outgoing_macro = outgoing_macro
        if outgoing_agent is not None:
            self.outgoing_agent = outgoing_agent
        if outgoing_contact_action is not None:
            self.outgoing_contact_action = outgoing_contact_action
        if outgoing_scheduled is not None:
            self.outgoing_scheduled = outgoing_scheduled
        if outgoing_api is not None:
            self.outgoing_api = outgoing_api
        if outgoing_channel_app is not None:
            self.outgoing_channel_app = outgoing_channel_app
        if outgoing_agent_app is not None:
            self.outgoing_agent_app = outgoing_agent_app
        if outgoing_customer_app is not None:
            self.outgoing_customer_app = outgoing_customer_app
        if engaged_customers is not None:
            self.engaged_customers = engaged_customers
        if outgoing_messages_text is not None:
            self.outgoing_messages_text = outgoing_messages_text
        if outgoing_messages_instant_app is not None:
            self.outgoing_messages_instant_app = outgoing_messages_instant_app
        if outgoing_messages_file is not None:
            self.outgoing_messages_file = outgoing_messages_file
        if outgoing_messages_mms is not None:
            self.outgoing_messages_mms = outgoing_messages_mms
        if outgoing_messages_system is not None:
            self.outgoing_messages_system = outgoing_messages_system
        if outgoing_contact_action_manual is not None:
            self.outgoing_contact_action_manual = outgoing_contact_action_manual
        if outgoing_contact_action_auto is not None:
            self.outgoing_contact_action_auto = outgoing_contact_action_auto
        if incoming_messages_text is not None:
            self.incoming_messages_text = incoming_messages_text
        if incoming_messages_mms is not None:
            self.incoming_messages_mms = incoming_messages_mms
        if total_segments is not None:
            self.total_segments = total_segments
        if outgoing_segments is not None:
            self.outgoing_segments = outgoing_segments
        if incoming_segments is not None:
            self.incoming_segments = incoming_segments

    @property
    def timestamp_epoch(self):
        """Gets the timestamp_epoch of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The timestamp at the start of the default group-by window as a Unix timestamp.  # noqa: E501

        :return: The timestamp_epoch of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp_epoch

    @timestamp_epoch.setter
    def timestamp_epoch(self, timestamp_epoch):
        """Sets the timestamp_epoch of this AnalyticsMessagingReportListItemModel.

        The timestamp at the start of the default group-by window as a Unix timestamp.  # noqa: E501

        :param timestamp_epoch: The timestamp_epoch of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._timestamp_epoch = timestamp_epoch

    @property
    def total_messages(self):
        """Gets the total_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent or received during the default group-by window.  # noqa: E501

        :return: The total_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._total_messages

    @total_messages.setter
    def total_messages(self, total_messages):
        """Sets the total_messages of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent or received during the default group-by window.  # noqa: E501

        :param total_messages: The total_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._total_messages = total_messages

    @property
    def outgoing_messages(self):
        """Gets the outgoing_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages

    @outgoing_messages.setter
    def outgoing_messages(self, outgoing_messages):
        """Sets the outgoing_messages of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent during the default group-by window.  # noqa: E501

        :param outgoing_messages: The outgoing_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages = outgoing_messages

    @property
    def incoming_messages(self):
        """Gets the incoming_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages received during the default group-by window.  # noqa: E501

        :return: The incoming_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_messages

    @incoming_messages.setter
    def incoming_messages(self, incoming_messages):
        """Sets the incoming_messages of this AnalyticsMessagingReportListItemModel.

        The total number of messages received during the default group-by window.  # noqa: E501

        :param incoming_messages: The incoming_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._incoming_messages = incoming_messages

    @property
    def outgoing_bot(self):
        """Gets the outgoing_bot of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent by a bot during the default group-by window.  # noqa: E501

        :return: The outgoing_bot of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_bot

    @outgoing_bot.setter
    def outgoing_bot(self, outgoing_bot):
        """Sets the outgoing_bot of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent by a bot during the default group-by window.  # noqa: E501

        :param outgoing_bot: The outgoing_bot of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_bot = outgoing_bot

    @property
    def outgoing_automation(self):
        """Gets the outgoing_automation of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent by an automation during the default group-by window.  # noqa: E501

        :return: The outgoing_automation of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_automation

    @outgoing_automation.setter
    def outgoing_automation(self, outgoing_automation):
        """Sets the outgoing_automation of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent by an automation during the default group-by window.  # noqa: E501

        :param outgoing_automation: The outgoing_automation of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_automation = outgoing_automation

    @property
    def outgoing_macro(self):
        """Gets the outgoing_macro of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent by an agent during the default group-by window.  # noqa: E501

        :return: The outgoing_macro of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_macro

    @outgoing_macro.setter
    def outgoing_macro(self, outgoing_macro):
        """Sets the outgoing_macro of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent by an agent during the default group-by window.  # noqa: E501

        :param outgoing_macro: The outgoing_macro of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_macro = outgoing_macro

    @property
    def outgoing_agent(self):
        """Gets the outgoing_agent of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent by a Library Action during the default group-by window.  # noqa: E501

        :return: The outgoing_agent of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_agent

    @outgoing_agent.setter
    def outgoing_agent(self, outgoing_agent):
        """Sets the outgoing_agent of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent by a Library Action during the default group-by window.  # noqa: E501

        :param outgoing_agent: The outgoing_agent of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_agent = outgoing_agent

    @property
    def outgoing_contact_action(self):
        """Gets the outgoing_contact_action of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of contact action messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_contact_action of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_contact_action

    @outgoing_contact_action.setter
    def outgoing_contact_action(self, outgoing_contact_action):
        """Sets the outgoing_contact_action of this AnalyticsMessagingReportListItemModel.

        The total number of contact action messages sent during the default group-by window.  # noqa: E501

        :param outgoing_contact_action: The outgoing_contact_action of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_contact_action = outgoing_contact_action

    @property
    def outgoing_scheduled(self):
        """Gets the outgoing_scheduled of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of scheduled messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_scheduled of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_scheduled

    @outgoing_scheduled.setter
    def outgoing_scheduled(self, outgoing_scheduled):
        """Sets the outgoing_scheduled of this AnalyticsMessagingReportListItemModel.

        The total number of scheduled messages sent during the default group-by window.  # noqa: E501

        :param outgoing_scheduled: The outgoing_scheduled of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_scheduled = outgoing_scheduled

    @property
    def outgoing_api(self):
        """Gets the outgoing_api of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via API during the default group-by window.  # noqa: E501

        :return: The outgoing_api of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_api

    @outgoing_api.setter
    def outgoing_api(self, outgoing_api):
        """Sets the outgoing_api of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via API during the default group-by window.  # noqa: E501

        :param outgoing_api: The outgoing_api of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_api = outgoing_api

    @property
    def outgoing_channel_app(self):
        """Gets the outgoing_channel_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via Channel App during the default group-by window.  # noqa: E501

        :return: The outgoing_channel_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_channel_app

    @outgoing_channel_app.setter
    def outgoing_channel_app(self, outgoing_channel_app):
        """Sets the outgoing_channel_app of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via Channel App during the default group-by window.  # noqa: E501

        :param outgoing_channel_app: The outgoing_channel_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_channel_app = outgoing_channel_app

    @property
    def outgoing_agent_app(self):
        """Gets the outgoing_agent_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via Agent App during the default group-by window.  # noqa: E501

        :return: The outgoing_agent_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_agent_app

    @outgoing_agent_app.setter
    def outgoing_agent_app(self, outgoing_agent_app):
        """Sets the outgoing_agent_app of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via Agent App during the default group-by window.  # noqa: E501

        :param outgoing_agent_app: The outgoing_agent_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_agent_app = outgoing_agent_app

    @property
    def outgoing_customer_app(self):
        """Gets the outgoing_customer_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via Customer App during the default group-by window.  # noqa: E501

        :return: The outgoing_customer_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_customer_app

    @outgoing_customer_app.setter
    def outgoing_customer_app(self, outgoing_customer_app):
        """Sets the outgoing_customer_app of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via Customer App during the default group-by window.  # noqa: E501

        :param outgoing_customer_app: The outgoing_customer_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_customer_app = outgoing_customer_app

    @property
    def engaged_customers(self):
        """Gets the engaged_customers of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of engaged customers during the default group-by window.  # noqa: E501

        :return: The engaged_customers of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._engaged_customers

    @engaged_customers.setter
    def engaged_customers(self, engaged_customers):
        """Sets the engaged_customers of this AnalyticsMessagingReportListItemModel.

        The total number of engaged customers during the default group-by window.  # noqa: E501

        :param engaged_customers: The engaged_customers of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._engaged_customers = engaged_customers

    @property
    def outgoing_messages_text(self):
        """Gets the outgoing_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of text messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_text

    @outgoing_messages_text.setter
    def outgoing_messages_text(self, outgoing_messages_text):
        """Sets the outgoing_messages_text of this AnalyticsMessagingReportListItemModel.

        The total number of text messages sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_text: The outgoing_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_text = outgoing_messages_text

    @property
    def outgoing_messages_instant_app(self):
        """Gets the outgoing_messages_instant_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of Instant Apps sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_instant_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_instant_app

    @outgoing_messages_instant_app.setter
    def outgoing_messages_instant_app(self, outgoing_messages_instant_app):
        """Sets the outgoing_messages_instant_app of this AnalyticsMessagingReportListItemModel.

        The total number of Instant Apps sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_instant_app: The outgoing_messages_instant_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_instant_app = outgoing_messages_instant_app

    @property
    def outgoing_messages_file(self):
        """Gets the outgoing_messages_file of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of files sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_file of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_file

    @outgoing_messages_file.setter
    def outgoing_messages_file(self, outgoing_messages_file):
        """Sets the outgoing_messages_file of this AnalyticsMessagingReportListItemModel.

        The total number of files sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_file: The outgoing_messages_file of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_file = outgoing_messages_file

    @property
    def outgoing_messages_mms(self):
        """Gets the outgoing_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of MMS messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_mms

    @outgoing_messages_mms.setter
    def outgoing_messages_mms(self, outgoing_messages_mms):
        """Sets the outgoing_messages_mms of this AnalyticsMessagingReportListItemModel.

        The total number of MMS messages sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_mms: The outgoing_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_mms = outgoing_messages_mms

    @property
    def outgoing_messages_system(self):
        """Gets the outgoing_messages_system of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of internal system messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_system of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_system

    @outgoing_messages_system.setter
    def outgoing_messages_system(self, outgoing_messages_system):
        """Sets the outgoing_messages_system of this AnalyticsMessagingReportListItemModel.

        The total number of internal system messages sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_system: The outgoing_messages_system of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_system = outgoing_messages_system

    @property
    def outgoing_contact_action_manual(self):
        """Gets the outgoing_contact_action_manual of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via manual (P2P) Contact Action during the default group-by window.  # noqa: E501

        :return: The outgoing_contact_action_manual of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_contact_action_manual

    @outgoing_contact_action_manual.setter
    def outgoing_contact_action_manual(self, outgoing_contact_action_manual):
        """Sets the outgoing_contact_action_manual of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via manual (P2P) Contact Action during the default group-by window.  # noqa: E501

        :param outgoing_contact_action_manual: The outgoing_contact_action_manual of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_contact_action_manual = outgoing_contact_action_manual

    @property
    def outgoing_contact_action_auto(self):
        """Gets the outgoing_contact_action_auto of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via automatic (A2P) Contact Action during the default group-by window.  # noqa: E501

        :return: The outgoing_contact_action_auto of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_contact_action_auto

    @outgoing_contact_action_auto.setter
    def outgoing_contact_action_auto(self, outgoing_contact_action_auto):
        """Sets the outgoing_contact_action_auto of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via automatic (A2P) Contact Action during the default group-by window.  # noqa: E501

        :param outgoing_contact_action_auto: The outgoing_contact_action_auto of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_contact_action_auto = outgoing_contact_action_auto

    @property
    def incoming_messages_text(self):
        """Gets the incoming_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of text messages received during the default group-by window.  # noqa: E501

        :return: The incoming_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_messages_text

    @incoming_messages_text.setter
    def incoming_messages_text(self, incoming_messages_text):
        """Sets the incoming_messages_text of this AnalyticsMessagingReportListItemModel.

        The total number of text messages received during the default group-by window.  # noqa: E501

        :param incoming_messages_text: The incoming_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._incoming_messages_text = incoming_messages_text

    @property
    def incoming_messages_mms(self):
        """Gets the incoming_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of MMS messages received during the default group-by window.  # noqa: E501

        :return: The incoming_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_messages_mms

    @incoming_messages_mms.setter
    def incoming_messages_mms(self, incoming_messages_mms):
        """Sets the incoming_messages_mms of this AnalyticsMessagingReportListItemModel.

        The total number of MMS messages received during the default group-by window.  # noqa: E501

        :param incoming_messages_mms: The incoming_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._incoming_messages_mms = incoming_messages_mms

    @property
    def total_segments(self):
        """Gets the total_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of segments sent and received during the default group-by window.  # noqa: E501

        :return: The total_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._total_segments

    @total_segments.setter
    def total_segments(self, total_segments):
        """Sets the total_segments of this AnalyticsMessagingReportListItemModel.

        The total number of segments sent and received during the default group-by window.  # noqa: E501

        :param total_segments: The total_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._total_segments = total_segments

    @property
    def outgoing_segments(self):
        """Gets the outgoing_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of segments sent during the default group-by window.  # noqa: E501

        :return: The outgoing_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_segments

    @outgoing_segments.setter
    def outgoing_segments(self, outgoing_segments):
        """Sets the outgoing_segments of this AnalyticsMessagingReportListItemModel.

        The total number of segments sent during the default group-by window.  # noqa: E501

        :param outgoing_segments: The outgoing_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_segments = outgoing_segments

    @property
    def incoming_segments(self):
        """Gets the incoming_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of segments received during the default group-by window.  # noqa: E501

        :return: The incoming_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_segments

    @incoming_segments.setter
    def incoming_segments(self, incoming_segments):
        """Sets the incoming_segments of this AnalyticsMessagingReportListItemModel.

        The total number of segments received during the default group-by window.  # noqa: E501

        :param incoming_segments: The incoming_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._incoming_segments = incoming_segments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsMessagingReportListItemModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsMessagingReportListItemModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.automations_api import AutomationsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAutomationsApi(unittest.TestCase):
    """AutomationsApi unit test stubs"""

    def setUp(self):
        self.api = AutomationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_org_channel(self):
        """Test case for add_org_channel

        Adds an OrgChannel to an automation  # noqa: E501
        """
        pass

    def test_create_automation(self):
        """Test case for create_automation

        Creates a new automation  # noqa: E501
        """
        pass

    def test_delete_automation(self):
        """Test case for delete_automation

        Deletes an automation  # noqa: E501
        """
        pass

    def test_delete_org_channel(self):
        """Test case for delete_org_channel

        Removes an OrgChannel from an automation  # noqa: E501
        """
        pass

    def test_get_automation(self):
        """Test case for get_automation

        Gets the details of a specific automation  # noqa: E501
        """
        pass

    def test_get_automations(self):
        """Test case for get_automations

        Gets all the automations in the org  # noqa: E501
        """
        pass

    def test_get_org_channels(self):
        """Test case for get_org_channels

        Gets a list of the OrgChannel from an automation  # noqa: E501
        """
        pass

    def test_update_automation(self):
        """Test case for update_automation

        Modifies an automation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.data_api import DataApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = DataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_data(self):
        """Test case for delete_data

        Deletes one key of data for a specific data entity  # noqa: E501
        """
        pass

    def test_get_data(self):
        """Test case for get_data

        Gets all the data for a specific data entity  # noqa: E501
        """
        pass

    def test_get_data_by_key(self):
        """Test case for get_data_by_key

        Gets one key of data for a specific data entity  # noqa: E501
        """
        pass

    def test_get_data_default(self):
        """Test case for get_data_default

        Get the default values for a specific customer data key  # noqa: E501
        """
        pass

    def test_get_data_defaults(self):
        """Test case for get_data_defaults

        Get the default values for customer data keys  # noqa: E501
        """
        pass

    def test_set_data(self):
        """Test case for set_data

        Sets all the data for a specific data entity (unmentioned keys are removed)  # noqa: E501
        """
        pass

    def test_set_data_default(self):
        """Test case for set_data_default

        Set the default value for a specific customer data key  # noqa: E501
        """
        pass

    def test_update_data(self):
        """Test case for update_data

        Updates data for a specific data entity (does not modify unmentioned keys)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.instant_app_schemas_api import InstantAppSchemasApi  # noqa: E501
from swagger_client.rest import ApiException


class TestInstantAppSchemasApi(unittest.TestCase):
    """InstantAppSchemasApi unit test stubs"""

    def setUp(self):
        self.api = InstantAppSchemasApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_schema(self):
        """Test case for activate_schema

        Activates or deactivates an Instant App Schema  # noqa: E501
        """
        pass

    def test_add_schema(self):
        """Test case for add_schema

        Creates an Instant App Schema  # noqa: E501
        """
        pass

    def test_delete_schema(self):
        """Test case for delete_schema

        Deletes an Instant App Schema  # noqa: E501
        """
        pass

    def test_get_schema(self):
        """Test case for get_schema

        Gets a specific Instant App Schema  # noqa: E501
        """
        pass

    def test_get_schema_info(self):
        """Test case for get_schema_info

        Gets details about a specific Instant App Schema  # noqa: E501
        """
        pass

    def test_get_schema_infos(self):
        """Test case for get_schema_infos

        Gets details about all of the Instant App Schemas in the org  # noqa: E501
        """
        pass

    def test_is_schema_active(self):
        """Test case for is_schema_active

        Gets the active status of an Instant App Schema  # noqa: E501
        """
        pass

    def test_update_schema(self):
        """Test case for update_schema

        Modifies an Instant App Schema  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from swagger_client.models.add_automation_model import AddAutomationModel
from swagger_client.models.add_bulk_action_fulfillment_model import AddBulkActionFulfillmentModel
from swagger_client.models.add_bulk_action_model import AddBulkActionModel
from swagger_client.models.add_bulk_action_variant_model import AddBulkActionVariantModel
from swagger_client.models.add_conversation_request_model import AddConversationRequestModel
from swagger_client.models.add_customer_model import AddCustomerModel
from swagger_client.models.add_identity_team_member_request_model import AddIdentityTeamMemberRequestModel
from swagger_client.models.add_or_update_automation_fulfillment_model import AddOrUpdateAutomationFulfillmentModel
from swagger_client.models.add_or_update_smart_link_fulfillment_model import AddOrUpdateSmartLinkFulfillmentModel
from swagger_client.models.add_or_update_smart_link_model import AddOrUpdateSmartLinkModel
from swagger_client.models.add_pool_channel_request_model import AddPoolChannelRequestModel
from swagger_client.models.add_pool_channel_response_model import AddPoolChannelResponseModel
from swagger_client.models.add_scheduled_action_model import AddScheduledActionModel
from swagger_client.models.add_team_member_model import AddTeamMemberModel
from swagger_client.models.admin_org_settings_model import AdminOrgSettingsModel
from swagger_client.models.analytics_agent_activity_report_model import AnalyticsAgentActivityReportModel
from swagger_client.models.analytics_api_report_model import AnalyticsApiReportModel
from swagger_client.models.analytics_bulk_action_report_model import AnalyticsBulkActionReportModel
from swagger_client.models.analytics_channel_report_model import AnalyticsChannelReportModel
from swagger_client.models.analytics_custom_counters_report_model import AnalyticsCustomCountersReportModel
from swagger_client.models.analytics_customer_engagement_report_model import AnalyticsCustomerEngagementReportModel
from swagger_client.models.analytics_error_report_model import AnalyticsErrorReportModel
from swagger_client.models.analytics_instant_app_report_model import AnalyticsInstantAppReportModel
from swagger_client.models.analytics_instant_app_schema_report_model import AnalyticsInstantAppSchemaReportModel
from swagger_client.models.analytics_kpi_report_model import AnalyticsKpiReportModel
from swagger_client.models.analytics_messaging_report_list_item_model import AnalyticsMessagingReportListItemModel
from swagger_client.models.analytics_messaging_report_model import AnalyticsMessagingReportModel
from swagger_client.models.analytics_opt_out_report_model import AnalyticsOptOutReportModel
from swagger_client.models.analytics_org_activity_report_model import AnalyticsOrgActivityReportModel
from swagger_client.models.api_key_model import ApiKeyModel
from swagger_client.models.api_key_model_page import ApiKeyModelPage
from swagger_client.models.audit_message_model import AuditMessageModel
from swagger_client.models.audit_message_model_page import AuditMessageModelPage
from swagger_client.models.automation_model import AutomationModel
from swagger_client.models.automation_model_page import AutomationModelPage
from swagger_client.models.bandwidth_org_channel_model import BandwidthOrgChannelModel
from swagger_client.models.bot_fulfillment_model import BotFulfillmentModel
from swagger_client.models.bot_intent_model import BotIntentModel
from swagger_client.models.bot_intent_phrase_model import BotIntentPhraseModel
from swagger_client.models.bot_intents_model import BotIntentsModel
from swagger_client.models.bot_model import BotModel
from swagger_client.models.bot_request_model import BotRequestModel
from swagger_client.models.bot_response_model import BotResponseModel
from swagger_client.models.bulk_action_confirmation_details_model import BulkActionConfirmationDetailsModel
from swagger_client.models.bulk_action_fulfillment_model import BulkActionFulfillmentModel
from swagger_client.models.bulk_action_model import BulkActionModel
from swagger_client.models.bulk_action_model_page import BulkActionModelPage
from swagger_client.models.bulk_action_perform_action_model import BulkActionPerformActionModel
from swagger_client.models.bulk_action_retarget_model import BulkActionRetargetModel
from swagger_client.models.bulk_action_variant_model import BulkActionVariantModel
from swagger_client.models.channel_id_model import ChannelIdModel
from swagger_client.models.contact import Contact
from swagger_client.models.contact_list_add_contacts_model import ContactListAddContactsModel
from swagger_client.models.contact_list_contact_model import ContactListContactModel
from swagger_client.models.contact_list_contact_model_page import ContactListContactModelPage
from swagger_client.models.contact_list_model import ContactListModel
from swagger_client.models.contact_list_model_page import ContactListModelPage
from swagger_client.models.conversation_bot_model import ConversationBotModel
from swagger_client.models.conversation_member_model import ConversationMemberModel
from swagger_client.models.conversation_model import ConversationModel
from swagger_client.models.conversation_model_page import ConversationModelPage
from swagger_client.models.custom_counter_report_key_value_pair import CustomCounterReportKeyValuePair
from swagger_client.models.customer_channel_model import CustomerChannelModel
from swagger_client.models.customer_identity_model import CustomerIdentityModel
from swagger_client.models.customer_message_model import CustomerMessageModel
from swagger_client.models.customer_model import CustomerModel
from swagger_client.models.customer_model_page import CustomerModelPage
from swagger_client.models.data_default_model import DataDefaultModel
from swagger_client.models.data_default_model_page import DataDefaultModelPage
from swagger_client.models.delete_response import DeleteResponse
from swagger_client.models.event_endpoint_model import EventEndpointModel
from swagger_client.models.event_endpoint_model_page import EventEndpointModelPage
from swagger_client.models.facebook_org_channel_model import FacebookOrgChannelModel
from swagger_client.models.fulfillment_model import FulfillmentModel
from swagger_client.models.google_map_integration_model import GoogleMapIntegrationModel
from swagger_client.models.google_sheets_integration_model import GoogleSheetsIntegrationModel
from swagger_client.models.group_member_model import GroupMemberModel
from swagger_client.models.group_member_model_page import GroupMemberModelPage
from swagger_client.models.group_model import GroupModel
from swagger_client.models.group_model_page import GroupModelPage
from swagger_client.models.historical_message_model import HistoricalMessageModel
from swagger_client.models.historical_message_model_page import HistoricalMessageModelPage
from swagger_client.models.instant_app_data_model import InstantAppDataModel
from swagger_client.models.instant_app_icon_model import InstantAppIconModel
from swagger_client.models.instant_app_model import InstantAppModel
from swagger_client.models.instant_app_model_page import InstantAppModelPage
from swagger_client.models.instant_app_report_key_value_pair import InstantAppReportKeyValuePair
from swagger_client.models.instant_app_schema_model import InstantAppSchemaModel
from swagger_client.models.instant_app_schema_model_page import InstantAppSchemaModelPage
from swagger_client.models.instant_app_timers_model import InstantAppTimersModel
from swagger_client.models.integration_request_model import IntegrationRequestModel
from swagger_client.models.integration_response_model import IntegrationResponseModel
from swagger_client.models.integration_response_model_page import IntegrationResponseModelPage
from swagger_client.models.key_value_data_model import KeyValueDataModel
from swagger_client.models.line_org_channel_model import LineOrgChannelModel
from swagger_client.models.location_model import LocationModel
from swagger_client.models.managed_bandwidth_org_channel_model import ManagedBandwidthOrgChannelModel
from swagger_client.models.map_icon_model import MapIconModel
from swagger_client.models.map_model import MapModel
from swagger_client.models.message_model import MessageModel
from swagger_client.models.messages_send_file_to_customer_body import MessagesSendFileToCustomerBody
from swagger_client.models.notification_group_model import NotificationGroupModel
from swagger_client.models.org_channel_conversations_model import OrgChannelConversationsModel
from swagger_client.models.org_channel_model import OrgChannelModel
from swagger_client.models.org_channel_model_page import OrgChannelModelPage
from swagger_client.models.org_channel_with_permissions_model import OrgChannelWithPermissionsModel
from swagger_client.models.org_channel_with_permissions_model_page import OrgChannelWithPermissionsModelPage
from swagger_client.models.org_external_id_model import OrgExternalIdModel
from swagger_client.models.org_messaging_settings_model import OrgMessagingSettingsModel
from swagger_client.models.org_model import OrgModel
from swagger_client.models.org_settings_model import OrgSettingsModel
from swagger_client.models.parameter import Parameter
from swagger_client.models.perform_action_model import PerformActionModel
from swagger_client.models.pool_channel_model import PoolChannelModel
from swagger_client.models.pool_channel_model_page import PoolChannelModelPage
from swagger_client.models.pool_model import PoolModel
from swagger_client.models.pool_model_page import PoolModelPage
from swagger_client.models.pool_subchannel_model import PoolSubchannelModel
from swagger_client.models.pool_subchannel_model_page import PoolSubchannelModelPage
from swagger_client.models.post_message_model import PostMessageModel
from swagger_client.models.post_whisper_model import PostWhisperModel
from swagger_client.models.pounce_model import PounceModel
from swagger_client.models.presence_summary_model import PresenceSummaryModel
from swagger_client.models.remove_team_member_from_conversation_request_model import RemoveTeamMemberFromConversationRequestModel
from swagger_client.models.resolution_contact_model import ResolutionContactModel
from swagger_client.models.resolution_count_model import ResolutionCountModel
from swagger_client.models.resolution_count_model_page import ResolutionCountModelPage
from swagger_client.models.sms_org_channel_model import SMSOrgChannelModel
from swagger_client.models.salesforce_integration_request_model import SalesforceIntegrationRequestModel
from swagger_client.models.salesforce_integration_response_model import SalesforceIntegrationResponseModel
from swagger_client.models.scheduled_action_fulfillment_model import ScheduledActionFulfillmentModel
from swagger_client.models.scheduled_action_model import ScheduledActionModel
from swagger_client.models.scheduled_action_model_page import ScheduledActionModelPage
from swagger_client.models.send_to_customer_message_model import SendToCustomerMessageModel
from swagger_client.models.smart_link_fulfillment_model import SmartLinkFulfillmentModel
from swagger_client.models.smart_link_model import SmartLinkModel
from swagger_client.models.smart_link_model_page import SmartLinkModelPage
from swagger_client.models.smooch_chat_org_channel_model import SmoochChatOrgChannelModel
from swagger_client.models.tag_group_model import TagGroupModel
from swagger_client.models.tag_group_model_page import TagGroupModelPage
from swagger_client.models.tag_model import TagModel
from swagger_client.models.tag_model_page import TagModelPage
from swagger_client.models.team_activity_event_model import TeamActivityEventModel
from swagger_client.models.team_activity_model import TeamActivityModel
from swagger_client.models.team_member_file_model_page import TeamMemberFileModelPage
from swagger_client.models.team_member_identity_model import TeamMemberIdentityModel
from swagger_client.models.team_member_model import TeamMemberModel
from swagger_client.models.team_member_model_page import TeamMemberModelPage
from swagger_client.models.team_member_notification_model import TeamMemberNotificationModel
from swagger_client.models.team_member_user_model import TeamMemberUserModel
from swagger_client.models.team_members_upload_body import TeamMembersUploadBody
from swagger_client.models.timer_info import TimerInfo
from swagger_client.models.twilio_integration_model import TwilioIntegrationModel
from swagger_client.models.twilio_org_channel_model import TwilioOrgChannelModel
from swagger_client.models.update_automation_model import UpdateAutomationModel
from swagger_client.models.update_customer_request_model import UpdateCustomerRequestModel
from swagger_client.models.update_instant_app_schema_active_model import UpdateInstantAppSchemaActiveModel
from swagger_client.models.update_map_icon_model import UpdateMapIconModel
from swagger_client.models.update_membership_command import UpdateMembershipCommand
from swagger_client.models.update_membership_model import UpdateMembershipModel
from swagger_client.models.update_pool_channel_status_request_model import UpdatePoolChannelStatusRequestModel
from swagger_client.models.update_team_member_request_model import UpdateTeamMemberRequestModel
from swagger_client.models.upload_model import UploadModel
from swagger_client.models.uploads_body import UploadsBody
from swagger_client.models.user_location_model import UserLocationModel
from swagger_client.models.ytel_org_channel_model import YtelOrgChannelModel
from swagger_client.models.zipwhip_org_channel_model import ZipwhipOrgChannelModel



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.pool_channels_api import PoolChannelsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestPoolChannelsApi(unittest.TestCase):
    """PoolChannelsApi unit test stubs"""

    def setUp(self):
        self.api = PoolChannelsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_channels(self):
        """Test case for add_channels

        Provision phone numbers for pool  # noqa: E501
        """
        pass

    def test_delete(self):
        """Test case for delete

        Delete a channel from a pool  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get a specific channel in a pool  # noqa: E501
        """
        pass

    def test_get_all(self):
        """Test case for get_all

        Get all the channels in a pool  # noqa: E501
        """
        pass

    def test_update_status(self):
        """Test case for update_status

        Updates the status of a specific channel in a pool  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class MessagesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_message(self, message_id, **kwargs):  # noqa: E501
        """Gets a single specific message by its internal id  # noqa: E501

        _in snippets: platform.api.messages.getMessage_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_message(message_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int message_id: (required)
        :return: MessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_message_with_http_info(message_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_message_with_http_info(message_id, **kwargs)  # noqa: E501
            return data

    def get_message_with_http_info(self, message_id, **kwargs):  # noqa: E501
        """Gets a single specific message by its internal id  # noqa: E501

        _in snippets: platform.api.messages.getMessage_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_message_with_http_info(message_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int message_id: (required)
        :return: MessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['message_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_message" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'message_id' is set
        if ('message_id' not in params or
                params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `get_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'message_id' in params:
            path_params['messageId'] = params['message_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/messages/{messageId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MessageModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_message_by_external_id(self, **kwargs):  # noqa: E501
        """Gets a single specific message by its external id  # noqa: E501

        _in snippets: platform.api.messages.getMessageByExternalId_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_message_by_external_id(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str by_channel_type:
        :param str by_external_message_id:
        :return: MessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_message_by_external_id_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_message_by_external_id_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_message_by_external_id_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a single specific message by its external id  # noqa: E501

        _in snippets: platform.api.messages.getMessageByExternalId_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_message_by_external_id_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str by_channel_type:
        :param str by_external_message_id:
        :return: MessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['by_channel_type', 'by_external_message_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_message_by_external_id" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'by_channel_type' in params:
            query_params.append(('by_channel_type', params['by_channel_type']))  # noqa: E501
        if 'by_external_message_id' in params:
            query_params.append(('by_external_message_id', params['by_external_message_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/messages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MessageModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_message_history(self, start_timestamp, **kwargs):  # noqa: E501
        """Gets historial messages in bulk  # noqa: E501

        _in snippets: platform.api.messages.getMessageHistory_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_message_history(start_timestamp, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_timestamp: (required)
        :param int end_timestamp:
        :param int first:
        :param int max:
        :return: HistoricalMessageModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_message_history_with_http_info(start_timestamp, **kwargs)  # noqa: E501
        else:
            (data) = self.get_message_history_with_http_info(start_timestamp, **kwargs)  # noqa: E501
            return data

    def get_message_history_with_http_info(self, start_timestamp, **kwargs):  # noqa: E501
        """Gets historial messages in bulk  # noqa: E501

        _in snippets: platform.api.messages.getMessageHistory_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_message_history_with_http_info(start_timestamp, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_timestamp: (required)
        :param int end_timestamp:
        :param int first:
        :param int max:
        :return: HistoricalMessageModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_timestamp', 'end_timestamp', 'first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_message_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'start_timestamp' is set
        if ('start_timestamp' not in params or
                params['start_timestamp'] is None):
            raise ValueError("Missing the required parameter `start_timestamp` when calling `get_message_history`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_timestamp' in params:
            query_params.append(('startTimestamp', params['start_timestamp']))  # noqa: E501
        if 'end_timestamp' in params:
            query_params.append(('endTimestamp', params['end_timestamp']))  # noqa: E501
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/messages/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='HistoricalMessageModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_file_to_customer(self, org_channel_id, customer_channel_key, customer_channel_id, message, ignore_delivery_restrictions, file, **kwargs):  # noqa: E501
        """Sends a file and an optional message to a customer, creating the customer, customer channel and conversation if needed.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_file_to_customer(org_channel_id, customer_channel_key, customer_channel_id, message, ignore_delivery_restrictions, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: (required)
        :param str customer_channel_key: (required)
        :param int customer_channel_id: (required)
        :param str message: (required)
        :param bool ignore_delivery_restrictions: (required)
        :param str file: (required)
        :return: CustomerMessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_file_to_customer_with_http_info(org_channel_id, customer_channel_key, customer_channel_id, message, ignore_delivery_restrictions, file, **kwargs)  # noqa: E501
        else:
            (data) = self.send_file_to_customer_with_http_info(org_channel_id, customer_channel_key, customer_channel_id, message, ignore_delivery_restrictions, file, **kwargs)  # noqa: E501
            return data

    def send_file_to_customer_with_http_info(self, org_channel_id, customer_channel_key, customer_channel_id, message, ignore_delivery_restrictions, file, **kwargs):  # noqa: E501
        """Sends a file and an optional message to a customer, creating the customer, customer channel and conversation if needed.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_file_to_customer_with_http_info(org_channel_id, customer_channel_key, customer_channel_id, message, ignore_delivery_restrictions, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: (required)
        :param str customer_channel_key: (required)
        :param int customer_channel_id: (required)
        :param str message: (required)
        :param bool ignore_delivery_restrictions: (required)
        :param str file: (required)
        :return: CustomerMessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'customer_channel_key', 'customer_channel_id', 'message', 'ignore_delivery_restrictions', 'file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_file_to_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `send_file_to_customer`")  # noqa: E501
        # verify the required parameter 'customer_channel_key' is set
        if ('customer_channel_key' not in params or
                params['customer_channel_key'] is None):
            raise ValueError("Missing the required parameter `customer_channel_key` when calling `send_file_to_customer`")  # noqa: E501
        # verify the required parameter 'customer_channel_id' is set
        if ('customer_channel_id' not in params or
                params['customer_channel_id'] is None):
            raise ValueError("Missing the required parameter `customer_channel_id` when calling `send_file_to_customer`")  # noqa: E501
        # verify the required parameter 'message' is set
        if ('message' not in params or
                params['message'] is None):
            raise ValueError("Missing the required parameter `message` when calling `send_file_to_customer`")  # noqa: E501
        # verify the required parameter 'ignore_delivery_restrictions' is set
        if ('ignore_delivery_restrictions' not in params or
                params['ignore_delivery_restrictions'] is None):
            raise ValueError("Missing the required parameter `ignore_delivery_restrictions` when calling `send_file_to_customer`")  # noqa: E501
        # verify the required parameter 'file' is set
        if ('file' not in params or
                params['file'] is None):
            raise ValueError("Missing the required parameter `file` when calling `send_file_to_customer`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'org_channel_id' in params:
            form_params.append(('orgChannelId', params['org_channel_id']))  # noqa: E501
        if 'customer_channel_key' in params:
            form_params.append(('customerChannelKey', params['customer_channel_key']))  # noqa: E501
        if 'customer_channel_id' in params:
            form_params.append(('customerChannelId', params['customer_channel_id']))  # noqa: E501
        if 'message' in params:
            form_params.append(('message', params['message']))  # noqa: E501
        if 'ignore_delivery_restrictions' in params:
            form_params.append(('ignoreDeliveryRestrictions', params['ignore_delivery_restrictions']))  # noqa: E501
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/messages/send_file_to_customer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerMessageModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_to_customer(self, **kwargs):  # noqa: E501
        """Sends a message and an optional instant app to a customer using API Ids, creating the customer, customer channel and conversation if needed.  # noqa: E501

        _in snippets: platform.api.messages.sendToCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_to_customer(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SendToCustomerMessageModel body:
        :return: CustomerMessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_to_customer_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.send_to_customer_with_http_info(**kwargs)  # noqa: E501
            return data

    def send_to_customer_with_http_info(self, **kwargs):  # noqa: E501
        """Sends a message and an optional instant app to a customer using API Ids, creating the customer, customer channel and conversation if needed.  # noqa: E501

        _in snippets: platform.api.messages.sendToCustomer_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_to_customer_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SendToCustomerMessageModel body:
        :return: CustomerMessageModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_to_customer" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/messages/send_to_customer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustomerMessageModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NotificationGroupModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'trigger': 'str',
        'send_sound': 'bool',
        'sound_url': 'str',
        'sound_volume': 'int',
        'sound_repeat_interval': 'int',
        'send_sms': 'bool',
        'phone_number': 'str',
        'send_email': 'bool',
        'slack_username': 'str',
        'slack_channel': 'str',
        'send_to_slack_username': 'bool',
        'mention_slack_user_name_in_channel': 'bool'
    }

    attribute_map = {
        'trigger': 'trigger',
        'send_sound': 'sendSound',
        'sound_url': 'soundUrl',
        'sound_volume': 'soundVolume',
        'sound_repeat_interval': 'soundRepeatInterval',
        'send_sms': 'sendSms',
        'phone_number': 'phoneNumber',
        'send_email': 'sendEmail',
        'slack_username': 'slackUsername',
        'slack_channel': 'slackChannel',
        'send_to_slack_username': 'sendToSlackUsername',
        'mention_slack_user_name_in_channel': 'mentionSlackUserNameInChannel'
    }

    def __init__(self, trigger=None, send_sound=None, sound_url=None, sound_volume=None, sound_repeat_interval=None, send_sms=None, phone_number=None, send_email=None, slack_username=None, slack_channel=None, send_to_slack_username=None, mention_slack_user_name_in_channel=None):  # noqa: E501
        """NotificationGroupModel - a model defined in Swagger"""  # noqa: E501
        self._trigger = None
        self._send_sound = None
        self._sound_url = None
        self._sound_volume = None
        self._sound_repeat_interval = None
        self._send_sms = None
        self._phone_number = None
        self._send_email = None
        self._slack_username = None
        self._slack_channel = None
        self._send_to_slack_username = None
        self._mention_slack_user_name_in_channel = None
        self.discriminator = None
        if trigger is not None:
            self.trigger = trigger
        if send_sound is not None:
            self.send_sound = send_sound
        if sound_url is not None:
            self.sound_url = sound_url
        if sound_volume is not None:
            self.sound_volume = sound_volume
        if sound_repeat_interval is not None:
            self.sound_repeat_interval = sound_repeat_interval
        if send_sms is not None:
            self.send_sms = send_sms
        if phone_number is not None:
            self.phone_number = phone_number
        if send_email is not None:
            self.send_email = send_email
        if slack_username is not None:
            self.slack_username = slack_username
        if slack_channel is not None:
            self.slack_channel = slack_channel
        if send_to_slack_username is not None:
            self.send_to_slack_username = send_to_slack_username
        if mention_slack_user_name_in_channel is not None:
            self.mention_slack_user_name_in_channel = mention_slack_user_name_in_channel

    @property
    def trigger(self):
        """Gets the trigger of this NotificationGroupModel.  # noqa: E501

        The event that triggers this notification to fire  # noqa: E501

        :return: The trigger of this NotificationGroupModel.  # noqa: E501
        :rtype: str
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this NotificationGroupModel.

        The event that triggers this notification to fire  # noqa: E501

        :param trigger: The trigger of this NotificationGroupModel.  # noqa: E501
        :type: str
        """

        self._trigger = trigger

    @property
    def send_sound(self):
        """Gets the send_sound of this NotificationGroupModel.  # noqa: E501


        :return: The send_sound of this NotificationGroupModel.  # noqa: E501
        :rtype: bool
        """
        return self._send_sound

    @send_sound.setter
    def send_sound(self, send_sound):
        """Sets the send_sound of this NotificationGroupModel.


        :param send_sound: The send_sound of this NotificationGroupModel.  # noqa: E501
        :type: bool
        """

        self._send_sound = send_sound

    @property
    def sound_url(self):
        """Gets the sound_url of this NotificationGroupModel.  # noqa: E501


        :return: The sound_url of this NotificationGroupModel.  # noqa: E501
        :rtype: str
        """
        return self._sound_url

    @sound_url.setter
    def sound_url(self, sound_url):
        """Sets the sound_url of this NotificationGroupModel.


        :param sound_url: The sound_url of this NotificationGroupModel.  # noqa: E501
        :type: str
        """

        self._sound_url = sound_url

    @property
    def sound_volume(self):
        """Gets the sound_volume of this NotificationGroupModel.  # noqa: E501


        :return: The sound_volume of this NotificationGroupModel.  # noqa: E501
        :rtype: int
        """
        return self._sound_volume

    @sound_volume.setter
    def sound_volume(self, sound_volume):
        """Sets the sound_volume of this NotificationGroupModel.


        :param sound_volume: The sound_volume of this NotificationGroupModel.  # noqa: E501
        :type: int
        """

        self._sound_volume = sound_volume

    @property
    def sound_repeat_interval(self):
        """Gets the sound_repeat_interval of this NotificationGroupModel.  # noqa: E501


        :return: The sound_repeat_interval of this NotificationGroupModel.  # noqa: E501
        :rtype: int
        """
        return self._sound_repeat_interval

    @sound_repeat_interval.setter
    def sound_repeat_interval(self, sound_repeat_interval):
        """Sets the sound_repeat_interval of this NotificationGroupModel.


        :param sound_repeat_interval: The sound_repeat_interval of this NotificationGroupModel.  # noqa: E501
        :type: int
        """

        self._sound_repeat_interval = sound_repeat_interval

    @property
    def send_sms(self):
        """Gets the send_sms of this NotificationGroupModel.  # noqa: E501


        :return: The send_sms of this NotificationGroupModel.  # noqa: E501
        :rtype: bool
        """
        return self._send_sms

    @send_sms.setter
    def send_sms(self, send_sms):
        """Sets the send_sms of this NotificationGroupModel.


        :param send_sms: The send_sms of this NotificationGroupModel.  # noqa: E501
        :type: bool
        """

        self._send_sms = send_sms

    @property
    def phone_number(self):
        """Gets the phone_number of this NotificationGroupModel.  # noqa: E501


        :return: The phone_number of this NotificationGroupModel.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this NotificationGroupModel.


        :param phone_number: The phone_number of this NotificationGroupModel.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def send_email(self):
        """Gets the send_email of this NotificationGroupModel.  # noqa: E501


        :return: The send_email of this NotificationGroupModel.  # noqa: E501
        :rtype: bool
        """
        return self._send_email

    @send_email.setter
    def send_email(self, send_email):
        """Sets the send_email of this NotificationGroupModel.


        :param send_email: The send_email of this NotificationGroupModel.  # noqa: E501
        :type: bool
        """

        self._send_email = send_email

    @property
    def slack_username(self):
        """Gets the slack_username of this NotificationGroupModel.  # noqa: E501


        :return: The slack_username of this NotificationGroupModel.  # noqa: E501
        :rtype: str
        """
        return self._slack_username

    @slack_username.setter
    def slack_username(self, slack_username):
        """Sets the slack_username of this NotificationGroupModel.


        :param slack_username: The slack_username of this NotificationGroupModel.  # noqa: E501
        :type: str
        """

        self._slack_username = slack_username

    @property
    def slack_channel(self):
        """Gets the slack_channel of this NotificationGroupModel.  # noqa: E501

        If set then a notification will be sent to this channel  # noqa: E501

        :return: The slack_channel of this NotificationGroupModel.  # noqa: E501
        :rtype: str
        """
        return self._slack_channel

    @slack_channel.setter
    def slack_channel(self, slack_channel):
        """Sets the slack_channel of this NotificationGroupModel.

        If set then a notification will be sent to this channel  # noqa: E501

        :param slack_channel: The slack_channel of this NotificationGroupModel.  # noqa: E501
        :type: str
        """

        self._slack_channel = slack_channel

    @property
    def send_to_slack_username(self):
        """Gets the send_to_slack_username of this NotificationGroupModel.  # noqa: E501


        :return: The send_to_slack_username of this NotificationGroupModel.  # noqa: E501
        :rtype: bool
        """
        return self._send_to_slack_username

    @send_to_slack_username.setter
    def send_to_slack_username(self, send_to_slack_username):
        """Sets the send_to_slack_username of this NotificationGroupModel.


        :param send_to_slack_username: The send_to_slack_username of this NotificationGroupModel.  # noqa: E501
        :type: bool
        """

        self._send_to_slack_username = send_to_slack_username

    @property
    def mention_slack_user_name_in_channel(self):
        """Gets the mention_slack_user_name_in_channel of this NotificationGroupModel.  # noqa: E501


        :return: The mention_slack_user_name_in_channel of this NotificationGroupModel.  # noqa: E501
        :rtype: bool
        """
        return self._mention_slack_user_name_in_channel

    @mention_slack_user_name_in_channel.setter
    def mention_slack_user_name_in_channel(self, mention_slack_user_name_in_channel):
        """Sets the mention_slack_user_name_in_channel of this NotificationGroupModel.


        :param mention_slack_user_name_in_channel: The mention_slack_user_name_in_channel of this NotificationGroupModel.  # noqa: E501
        :type: bool
        """

        self._mention_slack_user_name_in_channel = mention_slack_user_name_in_channel

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationGroupModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationGroupModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.team_members_api import TeamMembersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestTeamMembersApi(unittest.TestCase):
    """TeamMembersApi unit test stubs"""

    def setUp(self):
        self.api = TeamMembersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_identity1(self):
        """Test case for add_identity1

        Adds an identity to a team member  # noqa: E501
        """
        pass

    def test_add_team_member(self):
        """Test case for add_team_member

        Creates a team member  # noqa: E501
        """
        pass

    def test_delete_team_member(self):
        """Test case for delete_team_member

        Deletes a team member  # noqa: E501
        """
        pass

    def test_get_aggregate_permissions(self):
        """Test case for get_aggregate_permissions

        Gets a team member's permissions  # noqa: E501
        """
        pass

    def test_get_org_channel_permission1(self):
        """Test case for get_org_channel_permission1

        Gets a team member's orgChannel permission  # noqa: E501
        """
        pass

    def test_get_org_channel_permissions1(self):
        """Test case for get_org_channel_permissions1

        Gets a team member's orgChannel permissions  # noqa: E501
        """
        pass

    def test_get_org_channels_with_permissions(self):
        """Test case for get_org_channels_with_permissions

        Gets the org channels a team member has permissions for  # noqa: E501
        """
        pass

    def test_get_permission1(self):
        """Test case for get_permission1

        Gets a team member's permission  # noqa: E501
        """
        pass

    def test_get_permissions1(self):
        """Test case for get_permissions1

        Gets a team member's permissions  # noqa: E501
        """
        pass

    def test_get_private_apps(self):
        """Test case for get_private_apps

        Installs private agent app for the given agent  # noqa: E501
        """
        pass

    def test_get_shared_apps(self):
        """Test case for get_shared_apps

        Gets installed shared agent apps  # noqa: E501
        """
        pass

    def test_get_team_activity(self):
        """Test case for get_team_activity

        Returns a snapshot of team activity  # noqa: E501
        """
        pass

    def test_get_team_member(self):
        """Test case for get_team_member

        Gets the details for a specific team member  # noqa: E501
        """
        pass

    def test_get_team_member_activity(self):
        """Test case for get_team_member_activity

        Returns a snapshot of a team members activity  # noqa: E501
        """
        pass

    def test_get_team_member_notifications(self):
        """Test case for get_team_member_notifications

        Gets a team member's notification settings  # noqa: E501
        """
        pass

    def test_get_team_members(self):
        """Test case for get_team_members

        Gets all the team members in the org  # noqa: E501
        """
        pass

    def test_install_private_app(self):
        """Test case for install_private_app

        Installs private agent app for the given agent  # noqa: E501
        """
        pass

    def test_install_shared_app(self):
        """Test case for install_shared_app

        Installs shared agent app for all agents  # noqa: E501
        """
        pass

    def test_set_org_channel_permission(self):
        """Test case for set_org_channel_permission

        Sets a team member's orgChannel permission  # noqa: E501
        """
        pass

    def test_set_org_channel_permissions1(self):
        """Test case for set_org_channel_permissions1

        Sets a team member's orgChannel permissions  # noqa: E501
        """
        pass

    def test_set_permission(self):
        """Test case for set_permission

        Sets a team member's permission  # noqa: E501
        """
        pass

    def test_set_permissions1(self):
        """Test case for set_permissions1

        Sets a team member's permissions  # noqa: E501
        """
        pass

    def test_set_team_member_notifications(self):
        """Test case for set_team_member_notifications

        Sets a team member's notification settings  # noqa: E501
        """
        pass

    def test_update_team_member(self):
        """Test case for update_team_member

        Updates a team member  # noqa: E501
        """
        pass

    def test_upload_file_to_team_members(self):
        """Test case for upload_file_to_team_members

        Upload a file for specific team member(s) to access  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsApiReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp_epoch': 'int',
        'api_calls_success': 'int',
        'api_calls4xx': 'int',
        'api_calls5xx': 'int',
        'api_calls_total': 'int'
    }

    attribute_map = {
        'timestamp_epoch': 'timestampEpoch',
        'api_calls_success': 'apiCallsSuccess',
        'api_calls4xx': 'apiCalls4xx',
        'api_calls5xx': 'apiCalls5xx',
        'api_calls_total': 'apiCallsTotal'
    }

    def __init__(self, timestamp_epoch=None, api_calls_success=None, api_calls4xx=None, api_calls5xx=None, api_calls_total=None):  # noqa: E501
        """AnalyticsApiReportModel - a model defined in Swagger"""  # noqa: E501
        self._timestamp_epoch = None
        self._api_calls_success = None
        self._api_calls4xx = None
        self._api_calls5xx = None
        self._api_calls_total = None
        self.discriminator = None
        if timestamp_epoch is not None:
            self.timestamp_epoch = timestamp_epoch
        if api_calls_success is not None:
            self.api_calls_success = api_calls_success
        if api_calls4xx is not None:
            self.api_calls4xx = api_calls4xx
        if api_calls5xx is not None:
            self.api_calls5xx = api_calls5xx
        if api_calls_total is not None:
            self.api_calls_total = api_calls_total

    @property
    def timestamp_epoch(self):
        """Gets the timestamp_epoch of this AnalyticsApiReportModel.  # noqa: E501

        The timestamp at the start of the default group-by window as a Unix timestamp  # noqa: E501

        :return: The timestamp_epoch of this AnalyticsApiReportModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp_epoch

    @timestamp_epoch.setter
    def timestamp_epoch(self, timestamp_epoch):
        """Sets the timestamp_epoch of this AnalyticsApiReportModel.

        The timestamp at the start of the default group-by window as a Unix timestamp  # noqa: E501

        :param timestamp_epoch: The timestamp_epoch of this AnalyticsApiReportModel.  # noqa: E501
        :type: int
        """

        self._timestamp_epoch = timestamp_epoch

    @property
    def api_calls_success(self):
        """Gets the api_calls_success of this AnalyticsApiReportModel.  # noqa: E501

        The number of successful API calls in this group-by window.  # noqa: E501

        :return: The api_calls_success of this AnalyticsApiReportModel.  # noqa: E501
        :rtype: int
        """
        return self._api_calls_success

    @api_calls_success.setter
    def api_calls_success(self, api_calls_success):
        """Sets the api_calls_success of this AnalyticsApiReportModel.

        The number of successful API calls in this group-by window.  # noqa: E501

        :param api_calls_success: The api_calls_success of this AnalyticsApiReportModel.  # noqa: E501
        :type: int
        """

        self._api_calls_success = api_calls_success

    @property
    def api_calls4xx(self):
        """Gets the api_calls4xx of this AnalyticsApiReportModel.  # noqa: E501

        The number of API calls with an error code in the 4xx range in this group-by window.  # noqa: E501

        :return: The api_calls4xx of this AnalyticsApiReportModel.  # noqa: E501
        :rtype: int
        """
        return self._api_calls4xx

    @api_calls4xx.setter
    def api_calls4xx(self, api_calls4xx):
        """Sets the api_calls4xx of this AnalyticsApiReportModel.

        The number of API calls with an error code in the 4xx range in this group-by window.  # noqa: E501

        :param api_calls4xx: The api_calls4xx of this AnalyticsApiReportModel.  # noqa: E501
        :type: int
        """

        self._api_calls4xx = api_calls4xx

    @property
    def api_calls5xx(self):
        """Gets the api_calls5xx of this AnalyticsApiReportModel.  # noqa: E501

        The number of API calls with an error code in the 5xx range in this group-by window.  # noqa: E501

        :return: The api_calls5xx of this AnalyticsApiReportModel.  # noqa: E501
        :rtype: int
        """
        return self._api_calls5xx

    @api_calls5xx.setter
    def api_calls5xx(self, api_calls5xx):
        """Sets the api_calls5xx of this AnalyticsApiReportModel.

        The number of API calls with an error code in the 5xx range in this group-by window.  # noqa: E501

        :param api_calls5xx: The api_calls5xx of this AnalyticsApiReportModel.  # noqa: E501
        :type: int
        """

        self._api_calls5xx = api_calls5xx

    @property
    def api_calls_total(self):
        """Gets the api_calls_total of this AnalyticsApiReportModel.  # noqa: E501

        The total number of API calls in this group-by window.  # noqa: E501

        :return: The api_calls_total of this AnalyticsApiReportModel.  # noqa: E501
        :rtype: int
        """
        return self._api_calls_total

    @api_calls_total.setter
    def api_calls_total(self, api_calls_total):
        """Sets the api_calls_total of this AnalyticsApiReportModel.

        The total number of API calls in this group-by window.  # noqa: E501

        :param api_calls_total: The api_calls_total of this AnalyticsApiReportModel.  # noqa: E501
        :type: int
        """

        self._api_calls_total = api_calls_total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsApiReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsApiReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrgSettingsModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'force_change_password': 'bool',
        'password_reset_interval': 'int',
        'require_different_password': 'bool',
        'historical_password_count': 'int',
        'google_login_enabled': 'bool',
        'custom_general_status': 'str'
    }

    attribute_map = {
        'force_change_password': 'forceChangePassword',
        'password_reset_interval': 'passwordResetInterval',
        'require_different_password': 'requireDifferentPassword',
        'historical_password_count': 'historicalPasswordCount',
        'google_login_enabled': 'googleLoginEnabled',
        'custom_general_status': 'customGeneralStatus'
    }

    def __init__(self, force_change_password=None, password_reset_interval=None, require_different_password=None, historical_password_count=None, google_login_enabled=None, custom_general_status=None):  # noqa: E501
        """OrgSettingsModel - a model defined in Swagger"""  # noqa: E501
        self._force_change_password = None
        self._password_reset_interval = None
        self._require_different_password = None
        self._historical_password_count = None
        self._google_login_enabled = None
        self._custom_general_status = None
        self.discriminator = None
        if force_change_password is not None:
            self.force_change_password = force_change_password
        if password_reset_interval is not None:
            self.password_reset_interval = password_reset_interval
        if require_different_password is not None:
            self.require_different_password = require_different_password
        if historical_password_count is not None:
            self.historical_password_count = historical_password_count
        if google_login_enabled is not None:
            self.google_login_enabled = google_login_enabled
        if custom_general_status is not None:
            self.custom_general_status = custom_general_status

    @property
    def force_change_password(self):
        """Gets the force_change_password of this OrgSettingsModel.  # noqa: E501

        Force users to change password  # noqa: E501

        :return: The force_change_password of this OrgSettingsModel.  # noqa: E501
        :rtype: bool
        """
        return self._force_change_password

    @force_change_password.setter
    def force_change_password(self, force_change_password):
        """Sets the force_change_password of this OrgSettingsModel.

        Force users to change password  # noqa: E501

        :param force_change_password: The force_change_password of this OrgSettingsModel.  # noqa: E501
        :type: bool
        """

        self._force_change_password = force_change_password

    @property
    def password_reset_interval(self):
        """Gets the password_reset_interval of this OrgSettingsModel.  # noqa: E501

        The amount of days after a password is set until the next one is forced  # noqa: E501

        :return: The password_reset_interval of this OrgSettingsModel.  # noqa: E501
        :rtype: int
        """
        return self._password_reset_interval

    @password_reset_interval.setter
    def password_reset_interval(self, password_reset_interval):
        """Sets the password_reset_interval of this OrgSettingsModel.

        The amount of days after a password is set until the next one is forced  # noqa: E501

        :param password_reset_interval: The password_reset_interval of this OrgSettingsModel.  # noqa: E501
        :type: int
        """

        self._password_reset_interval = password_reset_interval

    @property
    def require_different_password(self):
        """Gets the require_different_password of this OrgSettingsModel.  # noqa: E501

        Do not allow previously used passwords to be recycled  # noqa: E501

        :return: The require_different_password of this OrgSettingsModel.  # noqa: E501
        :rtype: bool
        """
        return self._require_different_password

    @require_different_password.setter
    def require_different_password(self, require_different_password):
        """Sets the require_different_password of this OrgSettingsModel.

        Do not allow previously used passwords to be recycled  # noqa: E501

        :param require_different_password: The require_different_password of this OrgSettingsModel.  # noqa: E501
        :type: bool
        """

        self._require_different_password = require_different_password

    @property
    def historical_password_count(self):
        """Gets the historical_password_count of this OrgSettingsModel.  # noqa: E501

        Number of passwords required before a past password can be used again  # noqa: E501

        :return: The historical_password_count of this OrgSettingsModel.  # noqa: E501
        :rtype: int
        """
        return self._historical_password_count

    @historical_password_count.setter
    def historical_password_count(self, historical_password_count):
        """Sets the historical_password_count of this OrgSettingsModel.

        Number of passwords required before a past password can be used again  # noqa: E501

        :param historical_password_count: The historical_password_count of this OrgSettingsModel.  # noqa: E501
        :type: int
        """

        self._historical_password_count = historical_password_count

    @property
    def google_login_enabled(self):
        """Gets the google_login_enabled of this OrgSettingsModel.  # noqa: E501

        When enabled, users will be able to log-in with their Google authenticated credentials  # noqa: E501

        :return: The google_login_enabled of this OrgSettingsModel.  # noqa: E501
        :rtype: bool
        """
        return self._google_login_enabled

    @google_login_enabled.setter
    def google_login_enabled(self, google_login_enabled):
        """Sets the google_login_enabled of this OrgSettingsModel.

        When enabled, users will be able to log-in with their Google authenticated credentials  # noqa: E501

        :param google_login_enabled: The google_login_enabled of this OrgSettingsModel.  # noqa: E501
        :type: bool
        """

        self._google_login_enabled = google_login_enabled

    @property
    def custom_general_status(self):
        """Gets the custom_general_status of this OrgSettingsModel.  # noqa: E501

        Org-wide general status  # noqa: E501

        :return: The custom_general_status of this OrgSettingsModel.  # noqa: E501
        :rtype: str
        """
        return self._custom_general_status

    @custom_general_status.setter
    def custom_general_status(self, custom_general_status):
        """Sets the custom_general_status of this OrgSettingsModel.

        Org-wide general status  # noqa: E501

        :param custom_general_status: The custom_general_status of this OrgSettingsModel.  # noqa: E501
        :type: str
        """

        self._custom_general_status = custom_general_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrgSettingsModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrgSettingsModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
